from distutils.core import setup

setup(

    name = 'arjun_nester',
    version = '1.0.0',
    py_modules =['arjun_nester'],
    author = 'Arjun Prakash',
    author_email = 'arjuniyer.55@gmail.com',
    url = 'http://www.headfirstlabs.com',
    description = 'A Simple printer of nested lists',
    )



"""This module is defining a recursive function for printing out lists within lists"""

def print_lol(the_list):
    for each_item in the_list:
        if isinstance(each_item, list):
            print_lol(each_item)
        else:
            print(each_item)
			
         
